@@ -34,6 +34,7 @@ def sign(request: HttpRequest):
         email = request.POST['email']
         answer = request.POST['challenge_answer']
         signed_challenge_id = request.POST['challenge_id']
+        news = request.POST.get('news', 'off')
     except KeyError as e:
         return error_no_js(
             request,
@@ -41,6 +42,11 @@ def sign(request: HttpRequest):
             text="Veuillez remplir complètement le formulaire.",
         )
 
+    if news == 'on':
+        news = True
+    else:
+        news = False
+
     # challenge
     try:
         is_valid = check_answer_from_signed_challenge_id(signed_challenge_id, answer)
@@ -54,7 +60,11 @@ def sign(request: HttpRequest):
         )
 
     signature = Signature(
-        first_name=first_name, surname=surname, email=email, has_captcha_verified=False
+        first_name=first_name,
+        surname=surname,
+        email=email,
+        has_captcha_verified=False,
+        news=news,
     )
 
     try:
