@@ -36,7 +36,7 @@ class Signature(models.Model):
         except Signature.DoesNotExist:
             return False
 
-        signature.verified_at = date
+        signature.email_verified_at = date
         signature.save()
 
         return True
